@@ -6,19 +6,18 @@ DIFFCHECKER_AUTH_TOKEN: str = ''
 ETHERSCAN_API_KEY: str = ''
 
 
-def load_api_keys():
+def load_api_keys() -> None:
     home = os.path.expanduser('~')
     dirs = [home, '.', '..']
     keys = None
 
     for dir in dirs:
         try:
-            key_file = open(dir + '/api_keys.json', mode='r')
-        except:
+            with open(dir + '/api_keys.json', mode='r') as key_file:
+                keys = json.loads(key_file.read())
+        except FileNotFoundError:
             pass
         else:
-            with key_file:
-                keys = json.loads(key_file.read())
             break
 
     if keys is None:
@@ -30,10 +29,10 @@ def load_api_keys():
     DIFFCHECKER_AUTH_TOKEN = keys['diffchecker']
     ETHERSCAN_API_KEY = keys['etherscan']
 
-    
+
 def get_diffchecker_auth_token() -> str:
     return DIFFCHECKER_AUTH_TOKEN
 
 
 def get_etherscan_api_key() -> str:
-    return ETHERSCAN_API_KEY
\ No newline at end of file
+    return ETHERSCAN_API_KEY
