@@ -5,7 +5,7 @@ import json
 from smartdiffer.config import get_diffchecker_auth_token
 
 
-API_ENDPOINT = 'https://diffchecker-api-production.herokuapp.com'
+API_ENDPOINT = 'https://api.diffchecker.com'
 WEB_URL = 'https://www.diffchecker.com/'
 
 
@@ -16,7 +16,7 @@ def prep_diff(left: str, right: str) -> str:
     return url
 
 
-def _send_post_request(left: str = '', right: str = ''):
+def _send_post_request(left: str = '', right: str = '') -> requests.Response:
     data = {
         'Authorization': 'Bearer ' + get_diffchecker_auth_token(),
         'left': left,
@@ -24,8 +24,8 @@ def _send_post_request(left: str = '', right: str = ''):
         'expiry': 'day',
         'title': '',
     }
-    return requests.post(url = API_ENDPOINT + '/diffs', json = data)
+    return requests.post(url=API_ENDPOINT + '/diffs', json=data)
 
 
-def _retrieve_url(response):
-    return WEB_URL + json.loads(response.text)['slug']
\ No newline at end of file
+def _retrieve_url(response: requests.Response) -> str:
+    return WEB_URL + str(json.loads(response.text)['slug'])
